@@ -110,33 +110,13 @@ struct Plot<'a> {
     plots: Box<dyn PlotTrait + 'a>,
 }
 
-/// Shorthand for `moveable_format(move |w|write!(w,...))`
-/// Similar to `format_args!()` except has a more flexible lifetime.
-#[macro_export]
-macro_rules! move_format {
-    ($($arg:tt)*) => {
-        $crate::moveable_format(move |w| write!(w,$($arg)*))
-    }
-}
-
-/// Convert a moved closure into a impl fmt::Display.
-/// This is useful because std's `format_args!()` macro
-/// has a shorter lifetime.
-pub fn moveable_format(func: impl Fn(&mut fmt::Formatter) -> fmt::Result) -> impl fmt::Display {
-    struct Foo<F>(F);
-    impl<F: Fn(&mut fmt::Formatter) -> fmt::Result> fmt::Display for Foo<F> {
-        fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
-            (self.0)(formatter)
-        }
-    }
-    Foo(func)
-}
-
 /// Default theme using css variables (with light theme defaults if the variables are not set).
 pub const HTML_CONFIG_CSS_VARIABLE_DEFAULT: &str = "<style>.poloto {\
+    stroke-linecap:round;\
     font-family: sans-serif;\
     stroke-width:2;\
     }\
+    .scatter{stroke-width:7}\
     .poloto_text{fill: var(--poloto_fg_color,black);}\
     .poloto_axis_lines{stroke: var(--poloto_fg_color,black);stoke-width:3;fill:none}\
     .poloto_background{fill: var(--poloto_bg_color,aliceblue);}\
@@ -159,9 +139,11 @@ pub const HTML_CONFIG_CSS_VARIABLE_DEFAULT: &str = "<style>.poloto {\
 
 /// Default light theme
 pub const HTML_CONFIG_LIGHT_DEFAULT: &str = "<style>.poloto {\
+    stroke-linecap:round;\
     font-family: sans-serif;\
     stroke-width:2;\
     }\
+    .scatter{stroke-width:7}\
     .poloto_text{fill: black;}\
     .poloto_axis_lines{stroke: black;stoke-width:3;fill:none}\
     .poloto_background{fill: aliceblue;}\
@@ -184,9 +166,11 @@ pub const HTML_CONFIG_LIGHT_DEFAULT: &str = "<style>.poloto {\
 
 /// Default dark theme
 pub const HTML_CONFIG_DARK_DEFAULT: &str = "<style>.poloto {\
+    stroke-linecap:round;\
     font-family: sans-serif;\
     stroke-width:2;\
     }\
+    .scatter{stroke-width:7}\
     .poloto_text{fill: white;}\
     .poloto_axis_lines{stroke: white;stoke-width:3;fill:none}\
     .poloto_background{fill: black;}\
@@ -222,17 +206,16 @@ pub trait Plottable {
     fn make_plot(self) -> [f64; 2];
 }
 
-/// Poloto works with f64 numbers to scale/plot the graph
-/// Therefore all the number types supplied by the user must be convertable
-/// to f64. Precision loss is considered acceptable, since this is just for visual human eyes.
-pub trait IntoPlotNum: Copy {
-    fn into_plotnum(self) -> f64;
+/// Convert other primitive types to f64 using this trait.
+/// Precision loss is considered acceptable, since this is just for visual human eyes.
+pub trait IntoF64: Copy {
+    fn into_f64(self) -> f64;
 }
 
 macro_rules! impl_into_plotnum {
     ($U: ty ) => {
-        impl IntoPlotNum for $U {
-            fn into_plotnum(self) -> f64 {
+        impl IntoF64 for $U {
+            fn into_f64(self) -> f64 {
                 self as f64
             }
         }
@@ -254,31 +237,31 @@ impl_into_plotnum!(u128);
 impl_into_plotnum!(isize);
 impl_into_plotnum!(usize);
 
-impl<T: IntoPlotNum> Plottable for [T; 2] {
+impl<T: IntoF64> Plottable for [T; 2] {
     fn make_plot(self) -> [f64; 2] {
         let [x, y] = self;
-        [x.into_plotnum(), y.into_plotnum()]
+        [x.into_f64(), y.into_f64()]
     }
 }
 
-impl<T: IntoPlotNum> Plottable for &[T; 2] {
+impl<T: IntoF64> Plottable for &[T; 2] {
     fn make_plot(self) -> [f64; 2] {
         let [x, y] = self;
-        [x.into_plotnum(), y.into_plotnum()]
+        [x.into_f64(), y.into_f64()]
     }
 }
 
-impl<T: IntoPlotNum> Plottable for (T, T) {
+impl<T: IntoF64> Plottable for (T, T) {
     fn make_plot(self) -> [f64; 2] {
         let (x, y) = self;
-        [x.into_plotnum(), y.into_plotnum()]
+        [x.into_f64(), y.into_f64()]
     }
 }
 
-impl<T: IntoPlotNum> Plottable for &(T, T) {
+impl<T: IntoF64> Plottable for &(T, T) {
     fn make_plot(self) -> [f64; 2] {
         let (x, y) = self;
-        [x.into_plotnum(), y.into_plotnum()]
+        [x.into_f64(), y.into_f64()]
     }
 }
 
@@ -337,14 +320,20 @@ pub fn plot<'a>(
 /// Keeps track of plots.
 /// User supplies iterators that will be iterated on when
 /// render is called.
+///
+/// * The svg element belongs to the `poloto` css class.
+/// * The title,xname,yname,legend text SVG elements belong to the `poloto_text` class.
+/// * The axis line SVG elements belong to the `poloto_axis_lines` class.
+/// * The background belongs to the `poloto_background` class.
+///
 pub struct Plotter<'a> {
     names: Box<dyn Names + 'a>,
     plots: Vec<Plot<'a>>,
 }
 
 impl<'a> Plotter<'a> {
-    /// Create a line from plots.
-    /// Can be stylized using the `.poloto[N]stroke` css class.
+    /// Create a line from plots using a SVG polyline element.
+    /// The element belongs to the `.poloto[N]stroke` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
@@ -367,8 +356,8 @@ impl<'a> Plotter<'a> {
         self
     }
 
-    /// Create a line from plots that will be filled underneath.
-    /// Can be stylized using the `.poloto[N]fill` css class.
+    /// Create a line from plots that will be filled underneath using a SVG path element.
+    /// The path element belongs to the `.poloto[N]fill` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
@@ -391,7 +380,10 @@ impl<'a> Plotter<'a> {
         self
     }
 
-    /// Create a scatter plot from plots. Can be stylized using the `.poloto[N]fill` css class.
+    /// Create a scatter plot from plots, using a SVG path with lines with zero length.
+    /// Each point can be sized using the stroke width.
+    /// The path belongs to the CSS classes `scatter` and `.poloto[N]stroke` css class
+    /// with the latter class overriding the former.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
@@ -414,8 +406,9 @@ impl<'a> Plotter<'a> {
         self
     }
 
-    /// Create a histogram from plots.
-    /// Each bar's left side will line up with a point. Can be stylized using the `.poloto[N]fill` css class.
+    /// Create a histogram from plots using SVG rect elements.
+    /// Each bar's left side will line up with a point.
+    /// Each rect element belongs to the `.poloto[N]fill` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
@@ -438,50 +431,28 @@ impl<'a> Plotter<'a> {
         self
     }
 
-    /// Render to a `String`
+    ///
+    /// Use the plot iterators and generate out a [`RenderResult`] which implements [`std::fmt::Display`]
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
     /// let mut plotter = poloto::plot("title", "x", "y");
     /// plotter.line("", &data);
-    /// let s:String = plotter.render_to_string().unwrap();
+    /// let s = plotter.render().unwrap();
+    /// println!("{}",s);
     /// ```
-    pub fn render_to_string(self) -> Result<String, fmt::Error> {
-        let mut s = String::new();
-        self.render(&mut s)?;
-        Ok(s)
+    pub fn render(self) -> Result<RenderResult<'a>, fmt::Error> {
+        render::render(self)
     }
+}
 
-    /// Render to a `std::io::Write`
-    ///
-    /// ```
-    /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
-    /// let mut plotter = poloto::plot("title", "x", "y");
-    /// plotter.line("", &data);
-    /// plotter.render_io(std::io::stdout()).unwrap();
-    /// ```
-    pub fn render_io<T: std::io::Write>(self, writer: T) -> fmt::Result {
-        self.render(tagger::upgrade(writer))
-    }
-
-    /// Render the svg to the writer.
-    ///
-    /// Up until now, nothing has been written to the writer. We
-    /// have just accumulated a list of commands and closures. This call will
-    /// actually call all the closures and consume all the plot iterators.
-    ///
-    /// ```
-    /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
-    /// let mut plotter = poloto::plot("title", "x", "y");
-    /// plotter.line("", &data);
-    /// let mut s = String::new();
-    /// plotter.render(&mut s).unwrap();
-    /// ```
-    pub fn render<T: fmt::Write>(self, writer: T) -> fmt::Result {
-        let mut root = tagger::Element::new(writer);
-
-        render::render(root.get_writer(), self)?;
+///
+/// A rendered plot graph that implements [`std::fmt::Display`]
+///
+pub struct RenderResult<'a>(tagger::Element<'a>);
 
-        Ok(())
+impl fmt::Display for RenderResult<'_> {
+    fn fmt(&self, a: &mut fmt::Formatter) -> fmt::Result {
+        self.0.fmt(a)
     }
 }
